##  Filtering by Fields on Relation
You can use fields on relation as filter criteria to refine your search and gain better insights. Here are a few example queries that can be answered using fields on relation as filters:
  * All applications owned or used by an organization and not just related to an organization.
  * All applications where marketing is the leading business capability.
  * All applications where the data object 'Customer' is created or updated.
  * All IT components approved for the tech category 'Middleware'.


At the bottom of a filter group, the Add field filter drop-down list includes all default and custom fields on relations that you can select as filters. Select the necessary field from the list to apply the filter. You can select multiple fields in one search. Additionally, you can apply fields from multiple relations simultaneously by selecting the + Add relation field button, which appears after you have used at least one field on a relation as a filter.
![Filtering by Fields on Relation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749cae97a4410149beac58119c6de79_LowRes.png)
Filtering by Fields on Relation
